---
title: The History of the Computer

tags: computers programming computer-science history

cover_img_path: assets/images/posts/history-modern-computer.webp
---

Do you use a computer every day and wonder where it originated from?

This article steps through the history of computers, covering some firsts in technology and products as well as discussing the creators behind them.


## What is a computer?

A computer is a device that:

- Accepts data as input.
- Performs programmed mathematical and logical operations at high speed.
- Returns some results, such as performing a physical action or displaying the results of the operations.

Definition according to [Wikipedia](https://en.wikipedia.org/wiki/Computer):

> A computer is a machine that can be programmed to carry out sequences of arithmetic or logical operations automatically.


## Where is the term "computer" from?

A computer was originally a human clerk who completed calculations i.e. one who _computes_.

In the 1920s, the devices used to perform the tasks of the human computers were known as a "computing machine".

In the 1940s, this was simply called a "computer" - usually called an "electronic computer" or "digital computer".


## Why did computers evolve?

The invention of the computer in various forms introduced a lot of efficiencies, which made operations easier and sped up progress exponentially.

This has continued to modern-day life.

For example, in:

- Production, such as in factories.
- Instant data exchange, for business and social communication and interaction between machines.
- Administrative work, like booking flights and stock markets.
- Entertainment such as video and series.


## Early computers

### First computing device

To start our view of the history of the computer, we'll go back to the first computing device - the [abacus](https://en.wikipedia.org/wiki/Abacus).

This was first used as a tool for calculations by the Egyptians about 3500 years ago.

An abacus is a mechanical device, where the beads on the wires represent quantities and they slide on wires to show computations.


### First mechanical calculator

In the 1640s, [Blaise Pascal][] created the first [mechanical calculator][] or "calculating machine", at only age 19. This device is known as "Pascal's calculator" or "Pascalines".

It is capable of adding and subtracting numbers. It was created to help his father, a tax collector, calculate taxes owed and paid.

The [Pascal][] programming language owes its name to Blaise Pascal.

[Blaise Pascal]: https://en.wikipedia.org/wiki/Blaise_Pascal
[mechanical calculator]: https://en.wikipedia.org/wiki/Mechanical_calculator
[Pascal]: https://en.wikipedia.org/wiki/Pascal_(programming_language)


### First mechanical computer

In the 1830s, a British mathematician named [Charles Babbage][] conceptualized the first mechanical computer, and so he is regarded as the "father of computing".

He wrote a detailed description of what we now call the _Analytical Engine_. The machine's input was punch cards and its output was paper tape, but it had many similarities with modern computers.

Babbage is also credited with the design of the first modern programming language, which he called 'Scheme'.

[Charles Babbage]: https://en.wikipedia.org/wiki/Charles_Babbage


### First concept of the modern computer

In 1936, at Cambridge University, the mathematician and computer scientist [Alan Turing][] invented the principle of the modern computer.

His "Turing machine" was an abstract computer, a conceptual model, and not a real physical machine. The machine was used to formally define what would now be called "effective calculability" or "computability".

You may have heard of a concept named after Turing, called [Turing completeness][]. This is a way to express the power of a data manipulation rule set. Most programming languages of Turing Complete.

[Alan Turing]: https://en.wikipedia.org/wiki/Alan_Turing
[Turing complete]: https://en.wikipedia.org/wiki/Turing_completeness


### First electronic computer

In the 1940s, [Ada Lovelace][] created the first electronic computer. It consisted of a simple machine with electric circuits to perform mathematical calculations like addition and subtraction.

Ada had the [Ada][] programming language named after her.

[Ada Lovelace]: https://en.wikipedia.org/wiki/Ada_Lovelace
[Ada]: https://en.wikipedia.org/wiki/Ada_(programming_language)


### First general-purpose computer

In 1946, the _ENIAC_ was invented, abbreviated from "Electronic Numerical Integrator and Computer". It was the first general-purpose computer as it could be used for a variety of tasks. It was created to handle ballistic calculations for the military.

It also increased performance - while other computers could only manage a few instructions per second, the ENIAC could do a billion instructions per second.

It was the first _mainframe_ computer. A whole room was needed for one computer. It required about 200 feet of wiring to connect its 18,000 vacuum tubes.

The ENIAC was programmed by wires and switches. Data was entered through perforated paper tapes and punched cards, like Babbage's original invention.

## Modern computers

### First commercial computer

In the 1950s, IBM introduced the [IBM 704][] - the first mass-produced computer, with floating-point arithmetic hardware.

It could execute instructions at one-third the speed of contemporary machines, but it outsold other models due to its cheaper price per kilobyte,

A commercial computer in the early days cost $5,000 which is about $10,000 today.

It was also significant for having the first magnetic core memory.

[IBM 704]: https://en.wikipedia.org/wiki/IBM_704


## First personal computer

In 1966, IBM engineers designed a desktop computer small enough to place on a desk and call it the [IBM-PC][]. This computer changed computing and was popular with hobbyists because it could be customized with extra hardware and new software.

Before personal computers for the average person, computers were used in banks, government offices, and big corporations.

We could end our look at the history of the computer there, but let's go to some recent innovations in size and mobility.

[IBM-PC]: https://en.wikipedia.org/wiki/IBM_Personal_Computer


## First laptop

In 1998, the first laptop was launched by IBM.

In 2000, Apple followed with a competing device that is usually regarded as the first mass-market laptop, with a reduced size and weight.

## Compact smart devices

### First tablet

In 2004, Apple created the first tablet, named the [iPad][].

The iPad was a breakthrough in technology. It did not look like any computer before it. It did not work like any computer before it. However, the iPad had an impact on the development of computers because it popularized tablets and simplified our daily lives.

[iPad]: https://en.wikipedia.org/wiki/IPad


### First smartphone

A [smartphone][] is a portable device which can handle both mobile telephone and computing functions.

In 1992, IBM released a smartphone prototype called "Angler".

The device that is widely recognized as the first smartphone was Apple's [iPhone][]. Released in 2007, it has has become the most successful smartphone in the world. The idea for "responsive" websites that could be easily viewed on mobile phones was greatly influenced by the iPhone.

[smartphone]: https://en.wikipedia.org/wiki/Smartphone
[iPhone]: https://en.wikipedia.org/wiki/IPhone

### First Smartwatch

Around 2003, one of the first true smartwatches was released - the Microsoft SPOT (Smart Personal Object Technology). It was part of an initiative to improve the functionality of everyday objects like watches or keychains by embedding software.

The SPOT was a watch that aimed to give a distraction-free presentation of digital information. It could receive info around:

- weather
- news
- stock updates
- e-mail
- instant messages

Though there was no way to reply to messages and it required a $59/y subscription fee for updates.


## Resources

Some research that this article was based on.

- [List of pioneers in computer science](https://en.wikipedia.org/wiki/List_of_pioneers_in_computer_science) on Wikipedia.
- [A Brief History of the Computer](http://egov.uok.edu.in/elearningug/tutorials/7934_1_2016_161115135359.pdf) -
University of Kashmir
- [A Brief History of Computers](https://www.cs.uah.edu/~rcoleman/Common/History/History.html) - University of Alabama
- [The Modern History of Computing](https://plato.stanford.edu/entries/computing-history/) - Stanford Encyclopedia of Philosophy
- [History of the Computer](http://www.historyofcomputer.org/) website
- [A Brief History of the Microcomputer](https://turbofuture.com/computers/A-Brief-History-of-the-Micro-Computer)
- [Smartwatch timeline: The devices that paved the way for the Apple Watch](https://www.wareable.com/smartwatches/smartwatch-timeline-history-watches)

## Related DEV.to posts

- [The History behind the word “Computers”](https://dev.to/jay_tillu/the-history-behind-the-word-computers-549l)
- [Women's History Month: Computer Science Pioneers](https://dev.to/cher/women-s-history-month-computer-science-pioneers-71l)


## Credits

Photo by <a href="https://unsplash.com/@glenncarstenspeters?utm_source=unsplash&utm_medium=referral&utm_content=creditCopyText">Glenn Carstens-Peters</a> on <a href="https://unsplash.com/s/photos/old-computer?utm_source=unsplash&utm_medium=referral&utm_content=creditCopyText">Unsplash</a>

Edited with https://pixlr.com/e/
