---
title: AI chatbot options in 2023
description: 'Understanding use-cases and functionality around tools such as ChatGPT'
tags: ai productivity technology gpt
cover_img_path: assets/images/posts/ai-tools-text.jpg
---

I have a lot of experience with AI tools over the last few months and now I want to help you pick AI tools based on your use-cases or the functionality you're looking for. Including text processing, document analysis, speech input/output, image processing, and coding.

## AI-powered tools

An overview of the tools in this article, which are all free:

- [ChatGPT](https://chat.openai.com/) - the most famous one, by OpenAI. ChatGPT has limited speech and image functionality (at least on the free tier without plugins), and it cannot access the internet . So consider the other 3 options below to get access to these features. See OpenAI's overview page [here](https://openai.com/chatgpt).
- [Bing Chat](https://www.bing.com/search?q=Bing+AI&showconv=1&FORM=hpcodx) - Microsoft's AI chat built on a GPT model. Chats are limited to 30 prompts and input is limited (covered in a section below).
- [Google Bard](https://bard.google.com) - Google's AI chat built on Google's own model. See Google's post [here](https://blog.google/technology/ai/google-bard-updates-io-2023/).
- [Rix](https://hashnode.com/rix/) - an experimental AI by Hashnode, this is specialized for generating code answers and doing coding research. UPDATE: This is deprecated from 11 Dec 2023. They recommend GPT or [Perplexity](https://www.perplexity.ai/) as alternatives.


## Comparision

They can all produce creative writing, code, translation, and research. However, here are the differences as a table. This is expanded on in the rest of this article.

| Functionality                                 | ChatGPT (Free) | Bing Chat                       | Google Bard       |
| --------------------------------------------- | -------------- | ------------------------------- | ----------------- |
| Model                                         | GPT3           | GPT4                            | Gemini (Dec 2023) |
| Plugins/extensions                            | No             | Yes                             | Yes               |
| Text-to-speech                                | No             | Yes (only if you record speech) | Yes               |
| Speech-to-text (microphone)                   | No             | Yes                             | Yes               |
| Image generation                              | No             | Yes                             | No                |
| Read uploaded image or PDF                    | No             | Yes                             | Yes               |
| Access to the internet and provide references | No             | Yes                             | Yes               |
| Access to Google Drive                        | No             | No                              | Yes               |
| API available                                 | Yes            | No                              | Yes               |


## Summarizing text

The scenario is that you tell the AI to "summarize the following content", then you copy and paste an article into the chat.

This works really well in ChatGPT, as it handles a very large amount of input.

Bing Chat is considerably more limited in comparison. The entire chat is limited to 2000 tokens on Balanced (or 4000 on Creative or Precise modes). This is used up by pasting even a short article - this entire article of page or two didn't fit in when I asked to AI for tips on rewriting it. Also, on Bing Chat, the input _and_ the output of _each_ interaction in a chat counts towards the total, at least on previous releases I used.

I haven't tested the content length limitations of Rix or Google Bard, but both appear to comfortably handle articles that ChatGPT cannot.


## Documents and page context

Having the AI aware of the current page or a given document means it can look at the whole content without having to copy and paste it into the chat (especially if that content is too large to paste in). And you can give it asks like to summarize or to give a list of key action items. This is especially useful for personal research tasks or working through academic reading.

If you use the Bing Chat sidebar in the Edge browser (by clicking the Bing logo in the top right), you can talk to the AI with the context of the current page wherever you are.

For Google Bard, if you use the Google Drive or Google Documents extension, you can give it the name of a Google Document or PDF and ask it questions about it like to summarize or explain things. It can also help you find a document.

ChatGPT and Rix cannot be used with a sidebar or with documents.

## Image processing

### Image input

Bing Chat and Google Bard both let you upload an image so you can ask questions about it. While ChatGPT does not support this.

I don't really have a use-case for this. Sometimes I put in an AI art image and I see if it can give me appropriate words for the style to make a new image. Maybe this feature is useful for shopping for products or if you are outdoors and on your mobile phone and you want to get info on the sight or product you're looking at as a visual image search.

### Image generation

Bing Chat is capable of generating images using [Bing Image Creator][], which you can also use as a standalone tool.

The advantage of using it in the Bing Chat interface, is that it is more interactive - it has the context of your conversation and previous prompts and also it suggests things to do with the image as a next action like upsizing it or changing the details or style.

What is really impressive is that you can ask Bing Chat to write as text-to-image prompt and then generate an image with it immediately. I have got impressive results where I give it 2 words as inspiration and it created a detailed and effective prompt.

## Speech processing

### Speech-to-text

Bing Chat supports this with the microphone button. The other tools do not support this.

If you use ChatGPT through the mobile app rather than the website, than this does work I've been told.

### Text-to-Speech

If you use the Edge Browser, then any webpage or AI chatbox conversation can have text-to-speech with realistic voices. hre is the breakdown though without that.

For Bing Chat, if you use the microphone to input info, it will then read the response to you aloud. This voice is realistic.

For more customization and to use text-to-speech always (and not just in the microphone mode), you can also click the Edge browser's read aloud button near the address bar. It has a lot of languages and accents to choose from. This is also flexible - this would actually work with any AI tool and article.

Google Bard has the option to read responses aloud, but I found the speech somewhat robotic.

ChatGPT does not have this feature.

## Coding

Rix is specialized for writing code responses. It has 3 modes when starting a new thread:

- **web search** to get real-time info from the internet, with links to the articles it used.
- **quick mode** to use previously-stored knowledge.
- **code writer** to generate or modify code across multiple programming languages. It also gives explanations in between the code blocks.

Google Bard, ChatGPT, and Bing Chat also handle code well in my experience, but they are not specialists. So I tend to focus on my coding tasks on Rix.


## Research

Rix, Bing Chat, and Google Bard have access to the internet. They can do browser searches for you, provide links to sources, and some can read content at a URl you provide. Some can also provide embedded images.

This is great for coding problems as it they can search documentation and give links to articles and StackOverflow answers it used, so you can verify the answers.

You can also use these tools as super search engines. Rather than using the tools to give you answers, use them to refine your search query, scan many websites, and then give you links to the page. This can be especially useful for a Google search that is hard to phrase or a topic you know little about. Or just to accelerate the search process while still remaining in control.

If you use Google Bard with its extensions, it can integration with Google products for powerful searching. Including Google Maps, YouTube, and hotels. This makes it more powerful at getting accurate, recent information on the real world.

Bing Chat has plugins for recipes, online shopping, restaurant bookings, and holiday booking.

## Other tools

- [Bing Image Creator][] - this only generates AI art and has no interactive chat, but it does integrate well with Bing Chat.
- [Phind](https://www.phind.com/) - an AI search engine and "pair programmer" for debugging, with internet access and the option to use GPT-3 and GPT-4 models. A similar tool to Rix. Once I started using Rix, I haven't need the need to go back to Phind.
- [GitHub Copilot](https://github.com/features/copilot) - this is available as an extension like in VS Code. It is aware of your files and you don't have to leave your code editor and go to the browser. But, you have to pay $10 per month.


## Conclusion

Now with some more info on the strengths and limitations of each tool, you can go and pick one suitable for you next AI-assisted task.

Still not sure? Keep experimenting. I'd suggest putting the same prompt into multiple tools and seeing what results you get out of each. Sometimes one will need a lot of instruction to get good results. Or one will refuse to do something because it thinks the terms are violated (like if you ask for a "sarcastic" blog post).


## Cover image

Generated with [Bing Image Creator] and text added with [Pixlr](https://pixlr.com/x/#editor). Here is the [original](https://www.bing.com/images/create/horizontal-banner-for-blog-post-on-devto-about-ai/653e968c28fe4b7b87fc1c42bd8eda5a?id=QLslVZgVB4dBniYXnA%2b3Bw%3d%3d&view=detailv2&idpp=genimg&FORM=GCRIDP&ajaxhist=0&ajaxserp=0).

[Bing Image Creator]: https://www.bing.com/images/create
