---
title: AI as a language teacher
description: 'How to turn a chatbot into an interactive and informative language assistant'
tags: ai technology gpt language
cover_img_path: assets/images/posts/ai-language-teacher-text.jpg
---

I have a passion for languages and am excited to learn Dutch (in the Netherlands) as well as bits of other languages. AI tools like ChatGPT have made my learning process faster, more fun, and personalized. I'm here to share insights so you can achieve that too.

**Overview:**

- [Why use AI?](#why-use-ai)
- [Ways to use AI as a language tutor](#ways-to-use-ai-as-a-language-tutor)
    - [Conversational practice](#conversational-practice)
    - [Roleplaying scenarios](#roleplaying-scenarios)
    - [Engaging in debates](#engaging-in-debates)
    - [Learning about country and culture](#learning-about-country-and-culture)
    - [Translate content](#translate-content)
    - [Creative writing](#creative-writing)
    - [Generate words](#generate-words)
    - [Generate phrases](#generate-phrases)
    - [Translating across languages](#translating-across-languages)
    - [Phonetic pronunciation assistance](#phonetic-pronunciation-assistance)
    - [Ask for explanations](#ask-for-explanations)
        - [Slang](#slang)
        - [Abbreviations](#abbreviations)
    - [Requesting course outlines](#requesting-course-outlines)
    - [Play a game](#play-a-game)
- [Choose an AI tool](#choose-an-ai-tool)
- [Cover image](#cover-image)

## Why use AI?

Here are some challenges I encountered learning a language which I overcame with AI.

- In Duolingo, vocabulary acquisition for daily interactions happens very slow, the content often doesn't reflect casual usage or everyday purposes, and it only covers a single sentence at a time.
- Google Translate lacks context and is often too literal.
- Difficulty finding engaging content that is between beginner and intermediate levels.
- It was challenging to search online for language concepts when you observe grammar or informal speech but don't how to label it.
- A need for specific phrases beyond basics, like dentist appointments or describing your specific hobbies and your home country.
- Uncertainty about my learning path structure and identifying my weaknesses.
- A desire for having someone to practice with over text or voice, any time of day, for as long as a want. Especially on a train commute.


## Ways to use AI as a language tutor

Using AI, we can overcome the problems discussed above in a  Below are some approaches I recommend. The responses shown here are all from ChatGPT.


### Conversational practice

The simplest is just to start to talking to the AI in the language you want to learn and see the response in the same language.

```
Hoi, ik ben Michael. Hoe heet jij?
```

> Hoi Michael! Ik ben ChatGPT. Hoe gaat het met je vandaag?


Ask it at the start to correct your grammar and spelling if you make mistakes.

If you don't understand messages you get, ask for a translation of what was just said. Or ask the AI to give your answers in the target language and English in brackets for every message to you.

Give a topic or ask for topic suggestions or to pick one for you.

Get it to focus on asking you questions so keep you on your toes for responding to it. This might feel unnatural after a while though.

### Roleplaying scenarios

Ask to get the AI to get to know you, like as a best friend, acquaintance, or date. Get it to ask you some icebreaker questions.

```
Ask me a icebreaker question in beginner level Dutch
```

> _Natuurlijk! Wat zou jouw superkracht zijn als je er één mocht kiezen?_

Unforunately this case is not actually beginner level as asked, so you can try emphasizing that you want "basic vocabularly and grammary only". Or try Bing if you first tried ChatGPT.

If you have something more technical to prepare for, like a job interview or questions to expect for a presentation, get the AI to take on one of these roles. This will give more of a sense of interactivity and unpredictability of real life (unlike non-AI tools) while also giving relevant and knowledgable questions on your topic (it can be hard to find someone in-person who has this expertise).

Get the AI to talk you through a situation you want to prepare for. e.g. Interactions with a waiter, booking a flight online, phoning to make a doctor's appointment, or giving directions to someone. If you are stuck for ideas, get the AI to come up with situations based on your intention for being in the country or speaking the language. Such as when you are abroad or a holiday, studying or relocating.

### Engaging in debates

Have a debate on a current topic. Such as the impact of social media, AI, animal testing, free education, or veganism. Ask the AI to generate some topics that are popular or even ones it can find in this month's news.

I got this idea from [TalkPal.ai](https://talkpal.ai), which has Debate as a premium feature.

### Learning about country and culture

Are you interested in learning about the country you're in and how the culture? Ask the AI to give you some informative content about food, places, shopping, and so on.

```
I moved to the Netherlands! Give me a sentence talking about must-see attractions, food, and culture. Write it in Dutch and make it easy for a beginner to understand. Give me the English in brackets afterwards.
```

> _"Ik wil graag de molens in Kinderdijk zien, de stroopwafels proeven en de Nederlandse cultuur ervaren!" (I want to see the windmills in Kinderdijk, taste the stroopwafels, and experience Dutch culture!)_

### Translate content

Ask for translations and explanations about them. Whether from the conversation already in progress, or from text that you copy and paste. Give it an entire page if you want.

```
what does this mean in Dutch?

ter wereld
```

> _"Ter wereld" in Dutch translates to "in the world" or "on Earth" in English. It's used to refer to something happening or existing within the scope of the entire world or on a global scale._

Google Translate can be very literal and does not always capture the way a native would express themselves. The AI will have a better understanding of the context and intent and multiple meanings of a word.

If you have to submit a formal letter or you want to send a message to your neighbor on Whatsapp, ask the AI to check your content for errors or suggest improvements.

### Creative writing

Ask it to write a story at a level (e.g. absolute beginner, beginner, beginner-to-intermediate, or intermediate).

Pick a theme or genre that is interesting for you.  Ask it to write a story one paragraph or one chapter at a time, and on subsequent prompts say "next" or "more".

If the story gets boring you can ask for a plot twist or ask it to go in a certain direction.

Ask for explanations of words if you get stuck (it is also smart enough to explain the word in the context of the sentence).

```
Pitch me 3 bullet points of a kids story. In Dutch. Give me the English in brackets afterwards
```

- _Tim, een nieuwsgierige jongen, vindt een betoverde schatkist in het bos. (Tim, a curious boy, discovers an enchanted treasure chest in the forest.)_
- _In de kist zit een kaart die leidt naar een magische wereld vol pratende dieren. (Inside the chest, there's a map leading to a magical world inhabited by talking animals.)_
- _Samen met zijn nieuwe dierenvrienden gaat Tim op avontuur om een betovering te verbreken en de verdwenen koning terug te vinden. (With his newfound animal friends, Tim embarks on a quest to break a curse and find the missing king.)_

Over about a week, I worked with the AI to write kids adventure story in Dutch, where every day I asked for a new chapter (which ends up being a page long) and then I asked it questions on the words.

### Generate words

Ask for a table or list of words in a setting or theme.

If the language you are learning has a gender, ask for that too. e.g.

```
Give me a list as a table with columns for Dutch and English. Make sure to include the definite article in brackets before.
```

| Dutch           | English        |
| --------------- | -------------- |
| (de) boom       | (the) tree     |
| (het) huis      | (the) house    |
| (de) auto       | (the) car      |
| (het) boek      | (the) book     |
| (de) kat        | (the) cat      |
| (het) vliegtuig | (the) airplane |
| (de) tafel      | (the) table    |
| (het) raam      | (the) window   |
| (de) bloem      | (the) flower   |
| (het) bed       | (the) bed      |

Then simply ask for "more". Or give the AI more direction, like simpler or more advanced words or a different theme.

### Generate phrases

Ask the AI for a table of phrases, with columns for English and your chosen language. The phrases could be random or you could ask them to be in a sequence so it makes sense a story with questions and responses.

Do that for a particular situation like hobbies with a stranger, or in a restaurant or party or shop.

```
Give 5 polite phrases I can use at a restaurant such as to greet, order a meal, change the order, and pay and leave. Format as a table with Dutch and English columns.
```

| Dutch                                                | English                                             |
| ---------------------------------------------------- | --------------------------------------------------- |
| Goedemiddag, mag ik een tafel voor twee alstublieft? | Good afternoon, may I have a table for two, please? |
| Ik wil graag de kippensoep bestellen.                | I would like to order the chicken soup.             |
| Zou ik mijn bestelling kunnen wijzigen?              | Could I change my order, please?                    |
| Mag ik de rekening alstublieft?                      | Could I have the bill, please?                      |
| Bedankt, tot ziens!                                  | Thank you, goodbye!                                 |

For a more personal experience, cou could give it more context first about your personality and hobbies or favorite foods, then get it to start a conversation.

I am curious about learning a bit of a lot of languages. From my experience, I find this table-of-phrases approach way more effective and faster than using Duolingo (which is too slow and with a narrow structure) or finding an article online (which will have maybe 10 phrases and the next article will have mostly the same ones).

This approach is also great for learning informal aspects that might be in articles but not formal courses. Like slang, dialects, common informal expressions, and jokes.

```
Give me 3 slang phrases I can use with my friends. Format as a table in Dutch and English
```

| Dutch                    | English                    |
| ------------------------ | -------------------------- |
| "Dat is echt gaaf, man!" | "That's really cool, man!" |
| "Lekker bezig, gast!"    | "Nice going, dude!"        |
| "Effe chillen vanavond?" | "Wanna hang out tonight?"  |

### Translating across languages

You can ask for a table of multiple languages in one table e.g. English, Dutch, Spanish.

```
I work in IT. Give me 2 sentences for how to greet someone and say what I do for a living. Format a table of Dutch, French, and English.
```

| Dutch                                         | French                                                               | English                                       |
| --------------------------------------------- | -------------------------------------------------------------------- | --------------------------------------------- |
| "Goedemorgen! Ik werk in IT als programmeur." | "Bonjour! Je travaille dans l'informatique en tant que programmeur." | "Good morning! I work in IT as a programmer." |
| "Hallo! Ik ben een IT-beheerder."             | "Salut! Je suis administrateur en informatique."                     | "Hello! I'm an IT administrator."             |

### Phonetic pronunciation assistance

You could ask for a column that is the phonetic pronunciation. Especially for languages like Japanese, Greek, or Polish with unfamiliar alphabets.

```
Give me a table of greetings. Columns in English and Polish and pronunication in Polish
```

| English        | Polish        | Pronunciation (Polish) |
| -------------- | ------------- | ---------------------- |
| Hello          | Cześć         | cheshch                |
| Good morning   | Dzień dobry   | dzyen dob-ri           |
| Good afternoon | Dobry dzień   | dob-ri dzyen           |
| Good evening   | Dobry wieczór | dob-ri vyeh-choor      |
| Goodbye        | Do widzenia   | do veed-zen-ya         |
| Please         | Proszę        | proh-sheh              |
| Thank you      | Dziękuję      | jyen-koo-yeh           |
| Yes            | Tak           | tahk                   |
| No             | Nie           | nyeh                   |

Be careful of asking for "phonetic" pronunciation, as you get something more advanced phonetic standard. e.g. "Cześć" will appear as "'tʂɛɕt͡ɕ" rather than "cheshch".

### Ask for explanations

Sometimes I see something used a lot but it seems strange. And Google and Google Translate give bad results. So then I ask the AI.

#### Slang

```
In Dutch, I see people saying "ie" when as in "hoe gaat ie" or when they talk about an inanimate object. can you explain?
```

> _Certainly! In Dutch, "ie" is a colloquial way of saying "hij" or "het" in informal speech. It's a shortened, more casual form used in spoken language, particularly in informal settings or among friends and family._
>
> _For instance:_
> - _"Hoe gaat ie?" means "How is he/it doing?" but used informally to inquire about someone's well-being._
> - _"Die auto, hoeveel kost ie?" means "That car, how much does it cost?" using "ie" instead of "het" (it) in reference to an inanimate object._
> _It's a bit like saying "he" or "it" instead of "he/she/it" in English, but in Dutch, it's a more informal and shortened version._

#### Abbreviations

```
I see abbreviations, explain what they are

'k weet het.

't zusje.

's nachts.
```

> _Certainly! These are abbreviations commonly used in Dutch:_
>
> - _**'k weet het**: This stands for "ik weet het," which translates to "I know it" in English. It's a shortened form where the "ik" (I) is abbreviated to just the letter 'k to make the phrase more casual or quicker to say._
> - _**'t zusje**: This is an abbreviation for "het zusje" which means "the little sister" in English. The article "het" (the) is shortened to 't for ease of pronunciation or casual conversation._
> - _**'s nachts**: This stands for "des nachts" or "in de nacht" in full, both of which mean "at night" in English. The abbreviation 's represents "des" (of the), and it's commonly used in written and spoken Dutch to refer to activities or events happening during the nighttime._

### Requesting course outlines

Generate a curriculum or practice exercises appropriate for your level.

This can be high-level initially. Then you can ask to start one of the sections with content and questions. Or move on to another.

You could ask it to quiz you occasionally, or when it thinks the current section is complete.

### Play a game

Ask the AI to play a game. Such a guessing game inspired by 30 Seconds or 20 Questions, where the AI gives you a few attempts to guess the person or place, then it's your turn to give the hints.


## Choose an AI tool

Use your favorite AI chatbot for this. I found ChatGPT, Bing, and Google Bard all handle foreign languages well. I have an article on tradeoffs between them and with links to each, if you like - [AI chatbot options in 2023](https://michaelcurrin.github.io/coding-blog/2023/10/28/ai-tools.html).

To hear the speech spoken to you, you can use Bard with the speech icon. But I found it sounds artificial.

Bing Chat can speak to you and is more realistic, but it only gives audio response if you recorded with the microphone.

If you use the Edge browser, you can use a realistic text-to-speech service for any webpage, including any of the AI platforms you are using.

## Cover image

_Banner made with NightCafe, originally posted [here](https://creator.nightcafe.studio/creation/tiZVO63u6DiQB0cZvS7d)._
